@@ -205,15 +205,6 @@ def register_core_options():
         section="runner.output", key="color", default="auto", help_msg=help_msg
     )
 
-    help_msg = "Use UTF8 encoding (True or False)"
-    stgs.register_option(
-        section="runner.output",
-        key="utf8",
-        key_type=bool,
-        help_msg=help_msg,
-        default=True,
-    )
-
     help_msg = (
         "Suppress notification about broken plugins in the app "
         "standard error. Add the name of each broken plugin you "
@@ -228,11 +219,6 @@ def register_core_options():
         help_msg=help_msg,
     )
 
-    help_msg = "The encoding used by default on all data input"
-    stgs.register_option(
-        section="core", key="input_encoding", default="utf-8", help_msg=help_msg
-    )
-
     # All settings starting with 'runner.' will be passed to runner
     # exec-test runner config
     help_msg = (
@@ -270,13 +256,11 @@ def register_core_options():
         "installed and active implementations.  You can run "
         '"avocado plugins" and find the list of valid runners '
         'under the "Plugins that run test suites on a job '
-        '(runners) section.  Defaults to "nrunner", which is '
-        "the new runner and only runner supported at this moment. "
-        "This option name is currently DEPRECATED and will be "
-        'renamed to "run.suite_runner" on Avocado 100.0 and later.'
+        '(runners)" section.  Defaults to "nrunner", which is '
+        "the only runner that ships with core Avocado at this moment."
     )
     stgs.register_option(
-        section="run", key="test_runner", default="nrunner", help_msg=help_msg
+        section="run", key="suite_runner", default="nrunner", help_msg=help_msg
     )
 
 
