@@ -65,3 +65,24 @@ class BaseRunner(RunnableRunner):
             status = additional_info
         status.update({"status": status_type, "time": time.monotonic()})
         return status
+
+    def running_loop(self, condition):
+        """Produces timely running messages until end condition is found.
+
+        :param condition: a callable that will be evaluated as a
+                          condition for continuing the loop
+        """
+        most_current_execution_state_time = None
+        while not condition():
+            now = time.monotonic()
+            if most_current_execution_state_time is not None:
+                next_execution_state_mark = (
+                    most_current_execution_state_time + RUNNER_RUN_STATUS_INTERVAL
+                )
+            if (
+                most_current_execution_state_time is None
+                or now > next_execution_state_mark
+            ):
+                most_current_execution_state_time = now
+                yield self.prepare_status("running")
+            time.sleep(RUNNER_RUN_CHECK_INTERVAL)
