@@ -278,11 +278,11 @@ class Discoverer(Plugin, ResolverMixin):
         """
 
 
-class Runner(Plugin):
-    """Base plugin interface for test runners.
+class SuiteRunner(Plugin):
+    """Base plugin interface for runners for suites.
 
-    This is the interface a job uses to drive the tests execution via
-    compliant test runners.
+    This is the interface a job uses to drive the tests execution in a
+    suite.
 
     NOTE: This interface is not to be confused with the internal
     interface or idiosyncrasies of the :ref:`nrunner`.
@@ -454,7 +454,7 @@ class RunnableRunner(Plugin):
 
 
 class Cache(Plugin):
-    """Plugin for manipulating with cache interface"""
+    """Plugin for manipulating with cache metadata interface"""
 
     @abc.abstractmethod
     def list(self):
@@ -465,3 +465,10 @@ class Cache(Plugin):
         :return: Human-readable list of entries which will be printed to console.
         :rtype: str
         """
+
+    @abc.abstractmethod
+    def clear(self):
+        """Clear all cache entries
+
+        It removes every cache entire.
+        """
