@@ -28,14 +28,14 @@ LOG = logging.getLogger(__name__)
 
 
 #: The first two bytes that all gzip files start with
-GZIP_MAGIC = b'\037\213'
+GZIP_MAGIC = b"\037\213"
 
 
 def is_gzip_file(path):
     """
     Checks if file given by path has contents that suggests gzip file
     """
-    with open(path, 'rb') as gzip_file:  # pylint: disable=W1514
+    with open(path, "rb") as gzip_file:  # pylint: disable=W1514
         return gzip_file.read(len(GZIP_MAGIC)) == GZIP_MAGIC
 
 
@@ -43,13 +43,13 @@ def gzip_uncompress(path, output_path):
     """
     Uncompress a gzipped file at path, to either a file or dir at output_path
     """
-    with gzip.GzipFile(filename=path, mode='rb') as input_file:
+    with gzip.GzipFile(filename=path, mode="rb") as input_file:
         if os.path.isdir(output_path):
             basename = os.path.basename(path)
-            if basename.endswith('.gz'):
+            if basename.endswith(".gz"):
                 basename = basename[:-3]
             output_path = os.path.join(output_path, basename)
-        with open(output_path, 'wb') as output_file:
+        with open(output_path, "wb") as output_file:
             while True:
                 chunk = input_file.read(4096)
                 if not chunk:
@@ -62,7 +62,7 @@ def is_lzma_file(path):
     """
     Checks if file given by path has contents that suggests lzma file
     """
-    with lzma.LZMAFile(path, 'rb') as lzma_file:
+    with lzma.LZMAFile(path, "rb") as lzma_file:
         try:
             _ = lzma_file.read(1)
         except lzma.LZMAError:
@@ -80,13 +80,13 @@ def lzma_uncompress(path, output_path=None, force=False):
         output_path = os.path.splitext(path)[0]
     elif os.path.isdir(output_path):
         basename = os.path.basename(path)
-        if basename.endswith('.xz'):
+        if basename.endswith(".xz"):
             basename = os.path.splitext(basename)[0]
         output_path = os.path.join(output_path, basename)
     if not force and os.path.exists(output_path):
         return output_path
-    with lzma.open(path, 'rb') as file_obj:
-        with open(output_path, 'wb') as newfile_obj:
+    with lzma.open(path, "rb") as file_obj:
+        with open(output_path, "wb") as newfile_obj:
             newfile_obj.write(file_obj.read())
     return output_path
 
@@ -107,15 +107,16 @@ class ArchiveFile:
 
     # extension info: is_zip, is_tar, zipfile|tarfile, +mode
     _extension_table = {
-        '.zip': (True, False, zipfile.ZipFile, ''),
-        '.tar': (False, True, tarfile.open, ''),
-        '.tar.gz': (False, True, tarfile.open, ':gz'),
-        '.tgz': (False, True, tarfile.open, ':gz'),
-        '.tar.bz2': (False, True, tarfile.open, ':bz2'),
-        '.tbz2': (False, True, tarfile.open, ':bz2'),
-        '.xz': (False, True, tarfile.open, ':xz')}
+        ".zip": (True, False, zipfile.ZipFile, ""),
+        ".tar": (False, True, tarfile.open, ""),
+        ".tar.gz": (False, True, tarfile.open, ":gz"),
+        ".tgz": (False, True, tarfile.open, ":gz"),
+        ".tar.bz2": (False, True, tarfile.open, ":bz2"),
+        ".tbz2": (False, True, tarfile.open, ":bz2"),
+        ".xz": (False, True, tarfile.open, ":xz"),
+    }
 
-    def __init__(self, filename, mode='r'):
+    def __init__(self, filename, mode="r"):
         """
         Creates an instance of :class:`ArchiveFile`.
 
@@ -127,15 +128,12 @@ class ArchiveFile:
         engine = None
         for ext, value in ArchiveFile._extension_table.items():
             if filename.endswith(ext):
-                (self.is_zip,
-                 self.is_tar,
-                 engine,
-                 extra_mode) = value
+                (self.is_zip, self.is_tar, engine, extra_mode) = value
         if engine is not None:
             self.mode += extra_mode
             self._engine = engine(self.filename, self.mode)
         else:
-            raise ArchiveException('file is not an archive')
+            raise ArchiveException("file is not an archive")
 
     def __repr__(self):
         return f"ArchiveFile('{self.filename}', '{self.mode}')"
@@ -148,7 +146,7 @@ class ArchiveFile:
             self.close()
 
     @classmethod
-    def open(cls, filename, mode='r'):
+    def open(cls, filename, mode="r"):
         """
         Creates an instance of :class:`ArchiveFile`.
 
@@ -178,7 +176,7 @@ class ArchiveFile:
         else:
             self._engine.list()
 
-    def extract(self, path='.'):
+    def extract(self, path="."):
         """
         Extract all files from the archive.
 
@@ -208,18 +206,20 @@ class ArchiveFile:
         for path, info in self._engine.NameToInfo.items():
             dst = os.path.join(dst_dir, path)
             if not os.path.exists(dst):
-                LOG.warning("One or more files in the ZIP archive '%s' could "
-                            "not be found after extraction. Their paths are "
-                            "probably stored in unsupported format and their "
-                            "attributes are not going to be updated",
-                            self.filename)
+                LOG.warning(
+                    "One or more files in the ZIP archive '%s' could "
+                    "not be found after extraction. Their paths are "
+                    "probably stored in unsupported format and their "
+                    "attributes are not going to be updated",
+                    self.filename,
+                )
                 return
             attr = info.external_attr >> 16
             if attr & stat.S_IFLNK == stat.S_IFLNK:
                 dst = os.path.join(dst_dir, path)
                 if not os.path.islink(dst):
                     # Link created as an ordinary file containing the dst path
-                    with open(dst, 'r') as dst_path:  # pylint: disable=W1514
+                    with open(dst, "r") as dst_path:  # pylint: disable=W1514
                         src = dst_path.read()
                 else:
                     # Link is already there and could be outdated. Let's read
@@ -227,8 +227,8 @@ class ArchiveFile:
                     src = self._engine.read(path)
                 os.remove(dst)
                 os.symlink(src, dst)
-                continue    # Don't override any other attributes on links
-            mode = attr & 511   # Mask only permissions
+                continue  # Don't override any other attributes on links
+            mode = attr & 511  # Mask only permissions
             if mode and mode != 436:  # If mode is stored and is not default
                 os.chmod(dst, mode)
 
@@ -246,8 +246,12 @@ def is_archive(filename):
     :param filename: file to test.
     :return: `True` if it is an archive.
     """
-    return (zipfile.is_zipfile(filename) or tarfile.is_tarfile(filename) or
-            is_gzip_file(filename) or is_lzma_file(filename))
+    return (
+        zipfile.is_zipfile(filename)
+        or tarfile.is_tarfile(filename)
+        or is_gzip_file(filename)
+        or is_lzma_file(filename)
+    )
 
 
 def compress(filename, path):
@@ -258,13 +262,12 @@ def compress(filename, path):
     :param path: origin directory path to files to compress. No
                  individual files allowed.
     """
-    with ArchiveFile.open(filename, 'w') as x:
+    with ArchiveFile.open(filename, "w") as x:
         if os.path.isdir(path):
             for root, _, files in os.walk(path):
                 for name in files:
-                    newroot = root.replace(path, '')
-                    x.add(os.path.join(root, name),
-                          os.path.join(newroot, name))
+                    newroot = root.replace(path, "")
+                    x.add(os.path.join(root, name), os.path.join(newroot, name))
         elif os.path.isfile(path):
             x.add(path, os.path.basename(path))
 
