@@ -373,7 +373,7 @@ def create_suite_job_api(args):  # pylint: disable=W0621
                 "assert": True,
                 "reference": ["/bin/false", "/bin/true"],
                 "exit_code": 9,
-                "extra_job_config": {"nrunner.max_parallel_tasks": 1},
+                "extra_job_config": {"run.max_parallel_tasks": 1},
             },
             {
                 "namespace": "run.ignore_missing_references",
@@ -568,6 +568,13 @@ def create_suite_job_api(args):  # pylint: disable=W0621
 
 def create_suites(args):  # pylint: disable=W0621
     suites = []
+    config_check = {"run.ignore_missing_references": True}
+
+    if args.dict_tests["static-checks"]:
+        config_check_static = copy.copy(config_check)
+        config_check_static["resolver.references"] = glob.glob("selftests/*.sh")
+        suites.append(TestSuite.from_config(config_check_static, "static-checks"))
+
     # ========================================================================
     # Run nrunner interface checks for all available runners
     # ========================================================================
@@ -575,53 +582,26 @@ def create_suites(args):  # pylint: disable=W0621
         "resolver.references": ["selftests/functional/test_nrunner_interface.py"],
         "run.dict_variants.variant_id_keys": ["runner"],
         "run.dict_variants": [
-            {
-                "runner": "avocado-runner",
-                "runnable-run-no-args-exit-code": 2,
-                "runnable-run-uri-only-exit-code": 2,
-                "task-run-id-only-exit-code": 2,
-            },
             {
                 "runner": "avocado-runner-dry-run",
-                "runnable-run-no-args-exit-code": 0,
-                "runnable-run-uri-only-exit-code": 0,
-                "task-run-id-only-exit-code": 0,
             },
             {
                 "runner": "avocado-runner-noop",
-                "runnable-run-no-args-exit-code": 0,
-                "runnable-run-uri-only-exit-code": 0,
-                "task-run-id-only-exit-code": 0,
             },
             {
                 "runner": "avocado-runner-exec-test",
-                "runnable-run-no-args-exit-code": 0,
-                "runnable-run-uri-only-exit-code": 0,
-                "task-run-id-only-exit-code": 0,
             },
             {
                 "runner": "avocado-runner-python-unittest",
-                "runnable-run-no-args-exit-code": 0,
-                "runnable-run-uri-only-exit-code": 0,
-                "task-run-id-only-exit-code": 0,
             },
             {
                 "runner": "avocado-runner-avocado-instrumented",
-                "runnable-run-no-args-exit-code": 0,
-                "runnable-run-uri-only-exit-code": 0,
-                "task-run-id-only-exit-code": 0,
             },
             {
                 "runner": "avocado-runner-tap",
-                "runnable-run-no-args-exit-code": 0,
-                "runnable-run-uri-only-exit-code": 0,
-                "task-run-id-only-exit-code": 0,
             },
             {
                 "runner": "avocado-runner-podman-image",
-                "runnable-run-no-args-exit-code": 0,
-                "runnable-run-uri-only-exit-code": 0,
-                "task-run-id-only-exit-code": 0,
             },
         ],
     }
@@ -633,9 +613,6 @@ def create_suites(args):  # pylint: disable=W0621
         config_nrunner_interface["run.dict_variants"].append(
             {
                 "runner": "avocado-runner-golang",
-                "runnable-run-no-args-exit-code": 0,
-                "runnable-run-uri-only-exit-code": 0,
-                "task-run-id-only-exit-code": 0,
             }
         )
 
@@ -646,9 +623,6 @@ def create_suites(args):  # pylint: disable=W0621
         config_nrunner_interface["run.dict_variants"].append(
             {
                 "runner": "avocado-runner-robot",
-                "runnable-run-no-args-exit-code": 0,
-                "runnable-run-uri-only-exit-code": 0,
-                "task-run-id-only-exit-code": 0,
             }
         )
 
@@ -659,9 +633,6 @@ def create_suites(args):  # pylint: disable=W0621
         config_nrunner_interface["run.dict_variants"].append(
             {
                 "runner": "avocado-runner-ansible-module",
-                "runnable-run-no-args-exit-code": 0,
-                "runnable-run-uri-only-exit-code": 0,
-                "task-run-id-only-exit-code": 0,
             }
         )
 
@@ -675,7 +646,7 @@ def create_suites(args):  # pylint: disable=W0621
     # ========================================================================
     config_nrunner_requirement = {
         "resolver.references": ["selftests/functional/serial/test_requirements.py"],
-        "nrunner.max_parallel_tasks": 1,
+        "run.max_parallel_tasks": 1,
         "run.dict_variants": [
             {"spawner": "process"},
             {"spawner": "podman"},
@@ -691,10 +662,6 @@ def create_suites(args):  # pylint: disable=W0621
     # Run all static checks, unit and functional tests
     # ========================================================================
 
-    config_check = {
-        "run.ignore_missing_references": True,
-    }
-
     if args.dict_tests["unit"]:
         config_check_unit = copy.copy(config_check)
         config_check_unit["resolver.references"] = ["selftests/unit/"]
@@ -726,16 +693,11 @@ def create_suites(args):  # pylint: disable=W0621
         config_check_functional_serial["resolver.references"] = [
             "selftests/functional/serial/"
         ]
-        config_check_functional_serial["nrunner.max_parallel_tasks"] = 1
+        config_check_functional_serial["run.max_parallel_tasks"] = 1
         suites.append(
             TestSuite.from_config(config_check_functional_serial, "functional-serial")
         )
 
-    if args.dict_tests["static-checks"]:
-        config_check_static = copy.copy(config_check)
-        config_check_static["resolver.references"] = glob.glob("selftests/*.sh")
-        suites.append(TestSuite.from_config(config_check_static, "static-checks"))
-
     if args.dict_tests["optional-plugins"]:
         config_check_optional = copy.copy(config_check)
         config_check_optional["resolver.references"] = []
@@ -773,8 +735,8 @@ def main(args):  # pylint: disable=W0621
 
     # Print features covered in this test
     if args.list_features:
-        suites = create_suite_job_api(args)
-        suites += create_suites(args)
+        suites = create_suites(args)
+        suites += create_suite_job_api(args)
         features = []
         for suite in suites:
             for variants in suite.config["run.dict_variants"]:
@@ -816,10 +778,9 @@ def main(args):  # pylint: disable=W0621
         print("Something went wrong, please report a bug!")
         exit(1)
 
-    suites = []
+    suites = create_suites(args)
     if args.dict_tests["job-api"]:
         suites += create_suite_job_api(args)
-    suites += create_suites(args)
 
     # ========================================================================
     # Job execution
@@ -834,10 +795,18 @@ def main(args):  # pylint: disable=W0621
         max_parallel = int(multiprocessing.cpu_count() / 2)
         for suite in suites:
             if suite.name == "functional-parallel":
-                suite.config["nrunner.max_parallel_tasks"] = max_parallel
+                suite.config["run.max_parallel_tasks"] = max_parallel
 
     with Job(config, suites) as j:
+        pre_job_test_result_dirs = set(os.listdir(os.path.dirname(j.logdir)))
         exit_code = j.run()
+        post_job_test_result_dirs = set(os.listdir(os.path.dirname(j.logdir)))
+        if len(pre_job_test_result_dirs) != len(post_job_test_result_dirs):
+            if exit_code == 0:
+                exit_code = 1
+            print("check.py didn't clean test results.")
+            print("uncleaned directories:")
+            print(post_job_test_result_dirs.difference(pre_job_test_result_dirs))
     return exit_code
 
 
