@@ -109,6 +109,7 @@ OUTPUT_SHOW_TEST = """
 #!/usr/bin/env python3
 
 import sys
+import tempfile
 
 from avocado import Test
 from avocado.core.job import Job
@@ -117,21 +118,24 @@ from avocado.core.suite import TestSuite
 
 class PassTest(Test):
     def test1(self):
-        config = {'core.show': ['none'],
+        config = {'run.results_dir': self.workdir,
+                  'core.show': ['none'],
                   'resolver.references': ['/bin/true']}
         suite = TestSuite.from_config(config)
         with Job(config, [suite]) as j:
             j.run()
 
     def test2(self):
-        config = {'core.show': ['app'],
+        config = {'run.results_dir': self.workdir,
+                  'core.show': ['app'],
                   'resolver.references': ['/bin/true']}
         suite = TestSuite.from_config(config)
         with Job(config, [suite]) as j:
             j.run()
 
     def test3(self):
-        config = {'core.show': ['none'],
+        config = {'run.results_dir': self.workdir,
+                  'core.show': ['none'],
                   'resolver.references': ['/bin/true']}
         suite = TestSuite.from_config(config)
         with Job(config, [suite]) as j:
@@ -139,11 +143,16 @@ class PassTest(Test):
 
 
 if __name__ == '__main__':
-    config = {'resolver.references': [__file__],
+    test_results_dir = tempfile.TemporaryDirectory()
+
+    config = {'run.results_dir': test_results_dir.name,
+              'resolver.references': [__file__],
               'core.show': ['app']}
     suite = TestSuite.from_config(config)
     with Job(config, [suite]) as j:
-        sys.exit(j.run())
+        exit_code = j.run()
+        test_results_dir.cleanup()
+        sys.exit(exit_code)
 """
 
 
@@ -283,7 +292,7 @@ class OutputTest(TestCaseTmpDir):
             OUTPUT_SHOW_TEST,
             script.READ_ONLY_MODE,
         ) as test:
-            cmd = f"{AVOCADO} run --disable-sysinfo -- {test.path}"
+            cmd = f"{AVOCADO} run --disable-sysinfo --job-results-dir {self.tmpdir.name} -- {test.path}"
             result = process.run(cmd)
             expected_job_id_number = 1
             expected_bin_true_number = 0
@@ -427,6 +436,36 @@ class OutputPluginTest(TestCaseTmpDir):
         job_id = job_id_list[0]
         self.assertEqual(len(job_id), 40)
 
+    def test_show_custom_log(self):
+        cmd_line = (
+            f"{AVOCADO} --show=avocado.test.progress run "
+            f"--job-results-dir {self.tmpdir.name} "
+            f"--disable-sysinfo examples/tests/logging_streams.py"
+        )
+        result = process.run(cmd_line, ignore_status=True)
+        expected_rc = exit_codes.AVOCADO_ALL_OK
+        self.assertEqual(
+            result.exit_status,
+            expected_rc,
+            (f"Avocado did not return rc {expected_rc}:" f"\n{result}"),
+        )
+        self.assertEqual(
+            result.stdout_text,
+            (
+                "avocado.test.progress: 1-examples/tests/logging_streams.py:Plant.test_plant_organic: preparing soil on row 0\n"
+                "avocado.test.progress: 1-examples/tests/logging_streams.py:Plant.test_plant_organic: preparing soil on row 1\n"
+                "avocado.test.progress: 1-examples/tests/logging_streams.py:Plant.test_plant_organic: preparing soil on row 2\n"
+                "avocado.test.progress: 1-examples/tests/logging_streams.py:Plant.test_plant_organic: letting soil rest before throwing seeds\n"
+                "avocado.test.progress: 1-examples/tests/logging_streams.py:Plant.test_plant_organic: throwing seeds on row 0\n"
+                "avocado.test.progress: 1-examples/tests/logging_streams.py:Plant.test_plant_organic: throwing seeds on row 1\n"
+                "avocado.test.progress: 1-examples/tests/logging_streams.py:Plant.test_plant_organic: throwing seeds on row 2\n"
+                "avocado.test.progress: 1-examples/tests/logging_streams.py:Plant.test_plant_organic: waiting for Avocados to grow\n"
+                "avocado.test.progress: 1-examples/tests/logging_streams.py:Plant.test_plant_organic: harvesting organic avocados on row 0\n"
+                "avocado.test.progress: 1-examples/tests/logging_streams.py:Plant.test_plant_organic: harvesting organic avocados on row 1\n"
+                "avocado.test.progress: 1-examples/tests/logging_streams.py:Plant.test_plant_organic: harvesting organic avocados on row 2\n"
+            ),
+        )
+
     def test_silent_trumps_test(self):
         # Also verify --show=none can be supplied as run option
         cmd_line = (
