@@ -7,18 +7,17 @@ from selftests.utils import temp_dir_prefix
 
 
 class TestFileLock(unittest.TestCase):
-
     def setUp(self):
         prefix = temp_dir_prefix(self)
         self.tmpdir = tempfile.TemporaryDirectory(prefix=prefix)
-        self.filename = os.path.join(self.tmpdir.name, 'file.img')
-        self.content = 'Foo bar'
-        with open(self.filename, 'w', encoding='utf-8') as f:
+        self.filename = os.path.join(self.tmpdir.name, "file.img")
+        self.content = "Foo bar"
+        with open(self.filename, "w", encoding="utf-8") as f:
             f.write(self.content)
 
     def _readfile(self):
         with FileLock(self.filename):
-            with open(self.filename, 'r', encoding='utf-8') as f:
+            with open(self.filename, "r", encoding="utf-8") as f:
                 return f.read()
 
     def test_readfile(self):
@@ -29,8 +28,8 @@ class TestFileLock(unittest.TestCase):
             self.assertRaises(AlreadyLocked, self._readfile)
 
     def test_locked_by_other(self):
-        with open(self.filename+'.lock', 'w', encoding='utf-8') as f:
-            f.write('1')
+        with open(self.filename + ".lock", "w", encoding="utf-8") as f:
+            f.write("1")
         self.assertRaises(AlreadyLocked, self._readfile)
 
     def tearDown(self):
