@@ -70,13 +70,6 @@ class BaseIso9660:
         prefix = temp_dir_prefix(self)
         self.tmpdir = tempfile.TemporaryDirectory(prefix=prefix)
 
-    @unittest.skipIf(
-        os.uname()[4] == "s390x",
-        (
-            "Endianess issues on pycdlib, see "
-            "https://github.com/clalancette/pycdlib/issues/39"
-        ),
-    )
     def test_basic_workflow(self):
         """
         Check the basic Iso9660 workflow
@@ -96,11 +89,6 @@ class BaseIso9660:
         process.has_capability("cap_sys_admin"),
         "Capability to mount is required (cap_sys_admin)",
     )
-    @unittest.skipIf(
-        os.getenv("TRAVIS")
-        and os.getenv("TRAVIS_CPU_ARCH") in ["arm64", "ppc64le", "s390x"],
-        "TRAVIS Environment is unsuitable for these tests",
-    )
     def test_mnt_dir_workflow(self):
         """
         Check the mnt_dir functionality
@@ -166,11 +154,6 @@ class IsoMount(BaseIso9660, unittest.TestCase):
         process.has_capability("cap_sys_admin"),
         "Capability to mount is required (cap_sys_admin)",
     )
-    @unittest.skipIf(
-        os.getenv("TRAVIS")
-        and os.getenv("TRAVIS_CPU_ARCH") in ["arm64", "ppc64le", "s390x"],
-        "TRAVIS Environment is unsuitable for these tests",
-    )
     def setUp(self):
         super().setUp()
         self.iso = iso9660.Iso9660Mount(self.iso_path)
